fisx: Member List

fisx

fisx::SimpleSpecfile Member List

This is the complete list of members for fisx::SimpleSpecfile, including all inherited members.

getNumberOfScans() (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
getScanData(int scanIndex) (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
getScanHeader(int scanIndex) (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
getScanLabels(int scanIndex) (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
setFileName(std::string fileName) (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
SimpleSpecfile() (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |
SimpleSpecfile(std::string fileName) (defined in fisx::SimpleSpecfile) | fisx::SimpleSpecfile |